:mod:`art.experimental.estimators`
==================================
.. automodule:: art.experimental.estimators

Base Class JaxEstimator
-----------------------
.. autoclass:: JaxEstimator
   :members:
   :special-members: __init__
   :inherited-members:
